# gau_python

[![License](https://img.shields.io/badge/license-MIT-_red.svg)](https://opensource.org/licenses/MIT)
![PyPI](https://img.shields.io/pypi/v/gau-python?color=blue&logo=pypi&logoColor=yellow)

This library gets urls from AlienVault's Open Threat Exchange, the Wayback Machine, and Common Crawl. Inspired by [Corbin Leo's](https://github.com/lc) [gau](https://github.com/lc/gau)

### Installation
```
pip install gau-python
```

https://pypi.org/project/gau-python/

### Providers
This library gets urls from AlienVault's Open Threat Exchange, the Wayback Machine, and Common Crawl.

### Usage
To get all urls use:
```python
get_all_urls(domain)
```